<?php

namespace FiloBlu\CustomerBlocker\Observer\Sales;

class PaypalOrderPlaceBefore extends OrderPlaceBeforeAbstract {

    /**
     * Execute observer
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(
        \Magento\Framework\Event\Observer $observer
    ) {
        if($this->helper->isModuleEnable())
        {
            $order_email = $observer->getEvent()->getQuote()->getBillingAddress()->getEmail();

            $emailToBlock = $this->helper->isEmailToBeBlocked($order_email);
            $custormerAddressToBlock = $this->checkCustomerAddress($observer, true);

            if($custormerAddressToBlock || $emailToBlock) {
                throw new \Magento\Framework\Exception\LocalizedException(__("Sorry, your order cannot be processed."));
            }
        }

        if($this->helper->isCheckOrderAddressEnable())
        {
            $writer = new \Zend\Log\Writer\Stream(BP . '/var/log/customer_blocker.log');
            $logger = new \Zend\Log\Logger();
            $logger->addWriter($writer);

            $quote = $observer->getEvent()->getQuote();
            $msgDataIncomlete = "";

            $billignDataComplete = $this->helper->checkBillingAndShippingData($quote->getBillingAddress()->getData());

            if(!$quote->isVirtual()){
                $shippingDataComplete = $this->helper->checkBillingAndShippingData($quote->getShippingAddress()->getData());

                if(!$shippingDataComplete || !$billignDataComplete)
                {
                    $msgDataIncomlete = "Incomplete shipping or billing address data. Enter the missing data to place the order.";
                }
            }
            else{
                if(!$billignDataComplete)
                {
                    $msgDataIncomlete = "Incomplete billing address data. Enter the missing data to place the order.";
                }
            }

            if($msgDataIncomlete != "")
            {
                $logger->info('CUSTOMER BLOCKER - MISSING ADDRESS DATA');
                $logger->info('Quote id -> '.$quote->getId());
                $logger->info('Quote created at -> '.$quote->getCreatedAt());
                $logger->info('Customer is guest -> '.(is_null($quote->getCustomer()->getId()) ? 'YES' : 'NO, customer '.$quote->getCustomer()->getId()));
                $logger->info('Payment method -> '.$quote->getPayment()->getMethod());
                $logger->info('Billing Data:');
                $logger->info($quote->getBillingAddress()->getData());
                if(!$quote->isVirtual())
                {
                    $logger->info('Shipping Data:');
                    $logger->info($quote->getShippingAddress()->getData());
                }
                $logger->info('END CUSTOMER BLOCKER');
                throw new \Magento\Framework\Exception\LocalizedException(__($msgDataIncomlete));
            }
        }
    }
}